var struct__EnchantBroker =
[
    [ "_error", "struct__EnchantBroker.html#a88844610d8bba32f8ee527efdc987d9b", null ],
    [ "dicts", "struct__EnchantBroker.html#accd6f11dd22ef7cf5060bc709649ff30", null ],
    [ "provider_list", "struct__EnchantBroker.html#a1e9e2151bb451d8b7b3e5c1fe6017ad3", null ],
    [ "provider_ordering", "struct__EnchantBroker.html#afb3003e5e7ba68c446d0a016e8a8f0f1", null ]
];